@@ -19,9 +19,10 @@ def get_stack_info(stack_back_offset):
 # local log (globalスコープを汚さないログツール) [llog]
 class LLog:
 	# 初期化処理
-	def __init__(self, filename, additional):
+	def __init__(self, filename, additional = None):
 		self.filename = filename
 		self.additional = additional	# 追加記録事項
+		if self.additional is None: self.additional = {}
 		# ログ出力ファイルの作成
 		fileinit(self.filename, overwrite = False, init_str = "")	# ファイル初期化 [fileinit]
 	# ログ出力 (level: debug) [llog]
@@ -61,7 +62,7 @@ class LLog:
 		with open(self.filename, "a", encoding = "utf-8") as f:
 			f.write(json_str + "\n")
 	# 最新ログのレビュー (標準出力)
-	def tail(self, n = 10):
+	def tail(self, n = 10, show_flag = True):
 		# ログファイル読み込み
 		with open(self.filename, "r", encoding = "utf-8") as f:
 			raw_s = f.read()
@@ -70,6 +71,17 @@ class LLog:
 			for idx, s in enumerate(json_str_ls) if s.strip() != ""]
 		latest_ls = obj_ls[-n:]
 		# 表示
-		for idx, one_log in latest_ls:
-			print("[log #%d] "%idx, end = "")
-			sout(one_log)
+		if show_flag is True:
+			for idx, one_log in latest_ls:
+				print("[log #%d] "%idx, end = "")
+				sout(one_log)
+		return latest_ls
+	# for文脈に対応
+	def __iter__(self):
+		# ログファイル読み込み
+		with open(self.filename, "r", encoding = "utf-8") as f:
+			while True:
+				line = f.readline()
+				if line == "": break
+				obj = json.loads(line)
+				yield obj
